@@ -63,6 +63,7 @@ class PolicyKitService(dbus.service.Object):
         try:
             if sender:
                 kit = dbus.SystemBus().get_object('org.freedesktop.PolicyKit', '/')
+                kit = dbus.Interface(kit, 'org.freedesktop.PolicyKit')
                 pid = dbus.UInt32(os.getpid())
 
                 if 'yes' != kit.IsProcessAuthorized(action, pid, False):
@@ -244,7 +245,7 @@ class IrRecordDriver(ExternalToolDriver):
 
     # pylint: disable-msg=R0913
     def __init__(self, connection, driver, device,
-                 filename='lircd.conf', path=None):
+                 filename='lircd.conf.learning', path=None):
         assert not os.path.isabs(filename)
 
         if not path:
@@ -672,12 +673,72 @@ class BackendService(PolicyKitService):
             self._write_hardware_configuration(remote_values=values)
 
         # Write remote configuration:
+        filename, include_needed = lirc.find_remote_config()
 
-        filename = os.path.join(config.LIRC_CONFDIR, 'lircd.conf')
+        if include_needed:
+            self.__write_include_statement(filename)
+
+        print contents
 
         print 'Updating %s...' % filename
         file(filename, 'w').write(contents)
 
+    @staticmethod
+    def __write_include_statement(redirect):
+        '''Write include statement to central lircd.conf file.'''
+
+        # read central lirc configuration file file:
+        lircd_config = os.path.join(config.LIRC_CONFDIR, 'lircd.conf')
+
+        try:
+            contents = open(lircd_config).read()
+
+        except IOError:
+            contents = ''
+
+        # drop entire configuration file, if it still contains embedded
+        # configuration files - for instance from Gutsy:
+        pattern = r'^\s*begin\s+remote\s*$'
+        pattern = re.compile(pattern, re.MULTILINE)
+        match   = pattern.search(contents)
+
+        if match:
+            contents = ''
+
+        # find existing include statement:
+        include_statement = 'include %s\n' % redirect
+        pattern = r'^\s*(#.*)?include\s+%s\s*$' % re.escape(redirect)
+        pattern = re.compile(pattern, re.MULTILINE)
+        match   = pattern.search(contents)
+
+        if match is None:
+            # no statement found, create entirely new file:
+
+            if not contents:
+                contents  = '# This configuration has been automatically generated\n'
+                contents += '# by the GNOME LIRC Properties control panel.\n'
+                contents += '#\n'
+                contents += '# Feel free to add any custom remotes to the configuration\n'
+                contents += '# via additional include directives or below the existing\n'
+                contents += '# Ubuntu include directives from your selected remote and/or\n'
+                contents += '# transmitter.\n'
+                contents += '#\n'
+
+            contents += '\n'
+            contents += '# Configuration selected with GNOME LIRC Properties\n'
+            contents += include_statement
+
+        elif match.group(1):
+            head = contents[:match.start()]
+            tail = contents[match.end():]
+            contents = (head + include_statement + tail)
+
+        else:
+            contents = None
+
+        if contents:
+            open(lircd_config, 'w').write(contents)
+
     @dbus.service.method(dbus_interface=INTERFACE_NAME,
                          in_signature='', out_signature='',
                          sender_keyword='sender')
@@ -756,6 +817,7 @@ def get_service(bus=None):
         bus = get_service_bus()
 
     service = bus.get_object(BackendService.SERVICE_NAME, '/')
+    service = dbus.Interface(service, BackendService.INTERFACE_NAME)
 
     return service
 
