@@ -24,6 +24,7 @@ import errno, gobject, logging, os, re, tarfile
 from datetime              import datetime
 from gettext               import gettext as _
 from gnome_lirc_properties import config
+from locale                import LC_TIME, setlocale
 from StringIO              import StringIO
 from socket                import AF_UNIX, socket, error as SocketError
 
@@ -119,10 +120,12 @@ class Remote(object):
         Writes configuration file of this remote to writer.
         '''
 
-        # Write comment header with meta information
-
+        # Retrieve locale independent timestamp:
+        locale = setlocale(LC_TIME, 'C')
         now = datetime.now().strftime('%c')
+        setlocale(LC_TIME, locale)
 
+        # Write comment header with meta information:
         print >> writer, '# LIRC configuration file for %s' % self.name
         print >> writer, '# Generated by GNOME LIRC properties on %s' % now
         print >> writer, '# from %s' % self.filename
@@ -896,7 +899,7 @@ class KeyListener(gobject.GObject):
     # pylint: disable-msg=W0212,W1001
     connected = property(lambda self: None != self.__socket)
 
-class HardwareConfParser:
+class HardwareConfParser(object):
     '''
     Parse the (Debian/Ubuntu-specific) /etc/lirc/hardware.conf file.
 
@@ -943,3 +946,19 @@ class HardwareConfParser:
         except KeyError:
             return default
 
+def has_include_keyword():
+    '''Checks if include statements are supported in lircd.conf.'''
+
+    return (config.LSB_RELEASE.check(name='Ubuntu', codename='hardy') or
+            config.LSB_RELEASE.check(name='Ubuntu', release='8.04'))
+
+def find_remote_config():
+    '''Finds the location our customized lircd.conf file.'''
+
+    if has_include_keyword():
+        return os.path.join(config.LIRC_CONFDIR, 'lircd.conf.gnome'), True
+
+    return os.path.join(config.LIRC_CONFDIR, 'lircd.conf'), False
+
+if '__main__' == __name__:
+    print find_remote_config()
