@@ -376,7 +376,7 @@ class CustomConfiguration(object):
         self.__dialog.set_sensitive(False)
 
         net.post_file(target_uri=config.URI_UPLOADS,
-                      filename=config.LIRC_CONF_FILEPATH,
+                      filename=lirc.find_remote_config(),
                       content=self.__remote.configuration,
                       context=_('customized configuration file'),
                       finished_callback=on_upload_finished,
