@@ -19,7 +19,8 @@
 The main window of the application.
 '''
 
-import dbus, gobject, gtk, gtk.gdk, gtk.glade, httplib, locale, logging, os
+import dbus, errno, gobject, gtk, gtk.gdk, gtk.glade
+import httplib, locale, logging, os, subprocess
 
 from gettext               import gettext as _
 from gnome_lirc_properties import backend, config, lirc, model, hardware, policykit, net
@@ -591,11 +592,13 @@ class RemoteControlProperties(object):
                     break
 
                 except dbus.DBusException, ex:
-                    name = ex.get_dbus_name()
+                    exception_name = ex.get_dbus_name()
 
                     # The backend might complain
                     # that we have not yet requested authorization:
-                    if name == 'org.gnome.LircProperties.AccessDeniedException':
+                    if exception_name == 'org.gnome.LircProperties.AccessDeniedException':
+                        logging.debug('Access denied, reauthenticating: %r', ex)
+
                         #Request authorization from PolicyKit so we can try again.
                         granted = self._unlock()
 
@@ -607,7 +610,9 @@ class RemoteControlProperties(object):
                                          _('The System has refused access to this feature.'))
                             break # Stop trying.
 
-                    elif name.startswith('org.gnome.LircProperties.'):
+                    elif exception_name.startswith('org.gnome.LircProperties.'):
+                        logging.debug('Operation failed, aborting: %r', ex)
+
                         show_message(self.__dialog,
                                      _('Cannot Update Configuration'),
                                      _('Configuration backend reported %s.') % ex.message)
@@ -696,6 +701,10 @@ class RemoteControlProperties(object):
                             'was realized, but we need an xid')
             return False
 
+        if self.__auth.is_authorized():
+            logging.info('Authorized already. No need to obtain authorization.')
+            return True
+
         granted = self.__auth.obtain_authorization(self.__dialog)
 
         # Warn the user (because PolicyKit does not seem to)
@@ -729,16 +738,22 @@ class RemoteControlProperties(object):
     def _on_button_help_clicked(self, button):
         '''Handle "Help" button clicks.'''
 
+        display_name = self.__dialog.get_screen().make_display_name()
         args = 'yelp', 'ghelp:gnome-lirc-properties'
-        env = {'DISPLAY': self.__dialog.get_screen().make_display_name()}
-        pid = os.fork()
 
-        if 0 == pid:
-            os.environ.update(env)
-            os.execvp(args[0], args)
+        try:
+            subprocess.Popen(args, close_fds=True,
+                             env=dict(os.environ, DISPLAY=display_name))
 
-        elif -1 != pid:
-            os.waitpid(pid, os.P_NOWAIT)
+        except OSError, ex:
+            if errno.ENOENT == ex.errno:
+                error_message = _('Cannot display help since the GNOME Help ' +
+                                  'Browser ("yelp") cannot be found.')
+
+            else:
+                error_message = _('Cannot display help for unexpected reason: %s') % ex.strerror
+
+            show_message(self.__dialog, _('Cannot Display Help'), details=error_message)
 
     # pylint: disable-msg=R0201
     def _on_window_hide(self, window):
